@@ -199,6 +199,7 @@ class GlobalN(object):
 
     def add_items(self, items: list):
         """Add items."""
+        items = [hh for hh in items if hh is not None]
         l_name = [item.get_name() for item in items]
         s_name = set(l_name)
         if len(s_name) != len(l_name):
@@ -639,6 +640,8 @@ def transfer_cif_names_to_dict_names(variable_names):
             index = (0,)
         if name == "polarization":
             name = "beam_polarization"
+        elif name == "scale":
+            name = "phase_scale"
         elif name == "efficiency":
             name = "flipper_efficiency"
         elif name == "radius":
@@ -663,5 +666,22 @@ def transfer_cif_names_to_dict_names(variable_names):
         elif name == "chi_23":
             name = "atom_para_susceptibility"
             index = (5, index)
+        elif name == "u":
+            name = "resolution_parameters"
+            index = (0, )
+        elif name == "v":
+            name = "resolution_parameters"
+            index = (1, )
+        elif name == "w":
+            name = "resolution_parameters"
+            index = (2, )
+        elif name == "x":
+            name = "resolution_parameters"
+            index = (3, )
+        elif name == "y":
+            name = "resolution_parameters"
+            index = (4, )
+        if isinstance(index, int):
+            index = (index, )
         dict_names.append((data_block.lower(), name.lower(), index))
     return dict_names
\ No newline at end of file
